@@ -12,7 +12,7 @@ with rfem.Application() as rfem_app:
         results_type=rfem.results.ResultsType.STATIC_ANALYSIS_MEMBERS_INTERNAL_FORCES,
         filters=[
             rfem.results.ResultsFilter(column_id='member_no', filter_expression='1,2'),
-            rfem.results.ResultsFilter(column_id='loading', filter_expression='LC1, CO2'),
+            rfem.results.ResultsFilter(column_id='loading', filter_expression='LC1'),
         ]
     ).data
     print(f"\nInternal Forces | All:")
